@@ -66,9 +66,6 @@ class DSMREntity(object):
 
     return None
 
-
-
-
 class DSMRReader():
     def __init__(self, device = '/dev/ttyUSB0', serial_settings = SERIAL_SETTINGS_V2_2, telegram_specification = telegram_specifications.V2_2, debug=False):
         self.device                 = device
@@ -82,6 +79,41 @@ class DSMRReader():
             telegram_specification = self.telegram_specification
         )
 
+        self.obis_mapping_json = [
+            [
+                'power_consumption',
+                obis_ref.CURRENT_ELECTRICITY_USAGE
+            ],
+            [
+                'power_production',
+                obis_ref.CURRENT_ELECTRICITY_DELIVERY
+            ],
+            [
+                'power_tariff',
+                obis_ref.ELECTRICITY_ACTIVE_TARIFF
+            ],
+            [
+                'power_consumption_low',
+                obis_ref.ELECTRICITY_USED_TARIFF_1
+            ],
+            [
+                'power_consumption_normal',
+                obis_ref.ELECTRICITY_USED_TARIFF_2
+            ],
+            [
+                'power_production_low',
+                obis_ref.ELECTRICITY_DELIVERED_TARIFF_1
+            ],
+            [
+                'power_production_normal',
+                obis_ref.ELECTRICITY_DELIVERED_TARIFF_2
+            ],
+            [
+                'gas_consumption',
+                obis_ref.GAS_METER_READING
+            ]
+        ]
+
         self.obis_mapping = [
             [
                 'Power Consumption',
@@ -178,12 +210,13 @@ class DSMRReader():
             # ],
             ,
             [
-            'Gas Consumption',
-            obis_ref.GAS_METER_READING
+              'Gas Consumption',
+              obis_ref.GAS_METER_READING
             ]
         ]
 
-        self.devices = [DSMREntity(name, obis) for name, obis in self.obis_mapping]
+        # self.devices = [DSMREntity(name, obis) for name, obis in self.obis_mapping]
+        self.devices = [DSMREntity(name, obis) for name, obis in self.obis_mapping_json]
 
     def __update_entities_telegram(self, telegram):
         '''
@@ -205,19 +238,23 @@ class DSMRReader():
           for telegram in self.serial_reader.read():
 
             if (self.debug):
-              print(f">> BEFORE:\n\n{telegram}\n")
+              print(telegram)
 
             self.__update_entities_telegram(telegram)
 
-            if (self.debug):
-              print(f">> AFTER:\n\n{telegram}\n")
+            data = dict()
 
             for device in self.devices:
                 if device.unit_of_measurement == 'kW':
                     value = float(device.state()) * 1000
                 else:
                     value = device.state()
-                    print(f'{device.name} == {value} {device.unit_of_measurement or ""}')
+
+                # print(f'{device.name} == {value} {device.unit_of_measurement or ""}')
+
+                data[device.name] = value
+
+            print(json.dumps(data, indent=2))
 
 
             print('=' * 80)
